@@ -645,7 +645,7 @@ class Eniam():
                         collect_output = False
                         collect_png = True
                         png_files.append(new_file)
-                        #print("collect png mode")
+                        print(f"collect png mode => [{line_content}]")
                 if line_content.startswith("@end_pdf@"):
                     collect_pdf = False
                 else:
